@@ -9,6 +9,7 @@ pub struct EvalEnv<'r> {
     pub tr: &'r mut dyn Transaction,
     pub call_depth: usize,
 }
+
 impl<'r> EvalEnv<'r> {
     /// Construct a new EvalEnv.
     pub fn new(db: DB, tr: &'r mut dyn Transaction) -> Self {
@@ -247,7 +248,6 @@ impl<'r> EvalEnv<'r> {
             DO::DropFunction(name) => self.drop_function(name),
             DO::DropIndex(tname, iname) => self.drop_index(tname, iname),
             DO::AlterTable(tname, actions) => self.alter_table(tname, actions),
-            DO::RenameTable(_, _) => panic!(),
         }
     }
 
@@ -478,7 +478,7 @@ impl<'r> EvalEnv<'r> {
 
     fn drop_schema(&mut self, name: &str) {
         if let Some(sid) = sys::get_schema(&self.db, name) {
-            let sql = "EXEC sys.DropSchema(".to_string() + &sid.to_string() + ")";
+            let sql = format!("EXEC sys.DropSchema({})", sid);
             self.db.run(&sql, self.tr);
             self.db.schemas.borrow_mut().remove(name);
             self.db.function_reset.set(true);
@@ -489,7 +489,7 @@ impl<'r> EvalEnv<'r> {
 
     fn drop_table(&mut self, name: &ObjRef) {
         if let Some(t) = sys::get_table(&self.db, name) {
-            let sql = "EXEC sys.DropTable(".to_string() + &t.id.to_string() + ")";
+            let sql = format!("EXEC sys.DropTable({})", t.id);
             self.db.run(&sql, self.tr);
             self.db.tables.borrow_mut().remove(name);
             self.db.function_reset.set(true);
@@ -501,7 +501,7 @@ impl<'r> EvalEnv<'r> {
 
     fn drop_function(&mut self, name: &ObjRef) {
         if let Some(fid) = sys::get_function_id(&self.db, name) {
-            let sql = "DELETE FROM sys.Function WHERE Id = ".to_string() + &fid.to_string();
+            let sql = format!("DELETE FROM sys.Function WHERE Id = {}", fid);
             self.db.run(&sql, self.tr);
             self.db.function_reset.set(true);
         } else {
@@ -511,7 +511,7 @@ impl<'r> EvalEnv<'r> {
 
     fn drop_index(&mut self, tname: &ObjRef, iname: &str) {
         let (t, ix, id) = sys::get_index(&self.db, tname, iname);
-        let sql = "EXEC sys.DropIndex(".to_string() + &id.to_string() + ")";
+        let sql = format!("EXEC sys.DropIndex({})", id);
         self.db.run(&sql, self.tr);
         self.db.tables.borrow_mut().remove(tname);
         self.db.function_reset.set(true);
@@ -536,25 +536,13 @@ impl<'r> EvalEnv<'r> {
                 }
                 let sql = match act {
                     AlterCol::Add(name, typ) => {
-                        "EXEC sys.AddColumn(".to_string()
-                            + &t.id.to_string()
-                            + ",'"
-                            + name
-                            + "',"
-                            + &typ.to_string()
-                            + ")"
+                        format!("EXEC sys.AddColumn({},'{}',{})", t.id, name, typ)
                     }
                     AlterCol::Modify(name, typ) => {
-                        "EXEC sys.ModifyColumn(".to_string()
-                            + &t.id.to_string()
-                            + ",'"
-                            + name
-                            + "',"
-                            + &typ.to_string()
-                            + ")"
+                        format!("EXEC sys.ModifyColumn({},'{}',{})", t.id, name, typ)
                     }
                     AlterCol::Drop(name) => {
-                        "EXEC sys.DropColumn(".to_string() + &t.id.to_string() + ",'" + name + "')"
+                        format!("EXEC sys.DropColumn({},'{}')", t.id, name)
                     }
                 };
                 db.run(&sql, self.tr);
@@ -590,19 +578,18 @@ impl<'r> EvalEnv<'r> {
                 oldrow.load(db, data);
                 newrow.id = oldrow.id;
                 for (i, j) in colmap.iter().enumerate() {
-                    
                     newrow.values[i] = oldrow.values[*j].clone();
                 }
                 nt.insert(db, &mut newrow);
             }
-            let sql = "EXEC sys.AlterTable(".to_string() + &t.id.to_string() + ")";
+            let sql = format!("EXEC sys.ClearTable({})", t.id);
             db.run(&sql, self.tr);
             t.free_pages(db);
             sys::set_root(db, nt.id, root);
 
-            self.db.tables.borrow_mut().remove(name);
-            self.db.tables.borrow_mut().insert(name.clone(),nt);
-            self.db.function_reset.set(true);
+            db.tables.borrow_mut().remove(name);
+            db.tables.borrow_mut().insert(name.clone(), nt);
+            db.function_reset.set(true);
         } else {
             panic!("Alter Table not found {}", name.str());
         }
