@@ -508,7 +508,7 @@ GO
 
     /// Verify the page structure of the database.
     pub fn verify(self: &DB) -> String {
-        let (mut pages,total) = self.file.spd.file.read().unwrap().get_info();
+        let (mut pages, total) = self.file.spd.file.read().unwrap().get_info();
         let total = total as usize;
 
         let free = pages.len();
@@ -518,14 +518,18 @@ GO
         }
 
         let tm = &*self.tables.borrow();
-        for t in tm.values() 
-        {
-          t.get_used(self, &mut pages);
+        for t in tm.values() {
+            t.get_used(self, &mut pages);
         }
 
-        assert!( pages.len() == total );
+        assert!(pages.len() == total);
 
-        format!("All Ok. Logical page summary: free={} used={} total={}.", free, total-free, total)
+        format!(
+            "All Ok. Logical page summary: free={} used={} total={}.",
+            free,
+            total - free,
+            total
+        )
     }
 
     #[cfg(not(feature = "max"))]
