@@ -11,8 +11,19 @@ use crate::{nd, panic, util, Data, Ordering, Rc, Record, RefCell, DB};
 /// ```Rc<RefCell<Page>>```
 pub type PagePtr = Rc<RefCell<Page>>;
 
+/* Note: the page size must be big enough that a good number of records fits into a page.
+   A record with 20 fields of 16 bytes is 320 bytes.
+   The page size should be at least 2kb, and the constants below should be chosen to make this the case.
+*/
+
+// =1024. Size of an extension page.
+pub const EP_SIZE: usize = 1024;
+/// =16. Maximum number of extension pages.
+pub const EP_MAX: usize = 16;
+/// =136. Starter page size.
+pub const SP_SIZE: usize = (EP_MAX + 1) * 8;
 /// The maximum size in bytes of each page.
-pub const PAGE_SIZE: usize = 398 + (1024 - 16) * 16;
+pub const PAGE_SIZE: usize = (SP_SIZE - 2) + (EP_SIZE - 16) * EP_MAX;
 
 /// = 3. Size of Balance,Left,Right in a Node ( 2 + 2 x 11 = 24 bits = 3 bytes ).
 pub const NODE_OVERHEAD: usize = 3;
@@ -231,27 +242,25 @@ impl Page {
     }
 
     // Make a copy of a parent key record.
-    pub fn copy(&self, x: usize) -> Vec<u8>
-    {
-       let n = self.node_size - NODE_OVERHEAD - PAGE_ID_SIZE;
-       let off = self.rec_offset(x);
-       let mut b = vec![0;n];
-       b.copy_from_slice(&self.data[off..off + n]);
-       b
-    } 
+    pub fn copy(&self, x: usize) -> Vec<u8> {
+        let n = self.node_size - NODE_OVERHEAD - PAGE_ID_SIZE;
+        let off = self.rec_offset(x);
+        let mut b = vec![0; n];
+        b.copy_from_slice(&self.data[off..off + n]);
+        b
+    }
 
     // Append a copied parent key.
-    pub fn append_page_copy(&mut self, b: &[u8], cp: u64 )
-    {
+    pub fn append_page_copy(&mut self, b: &[u8], cp: u64) {
         let inserted = self.next_alloc();
         self.root = self.insert_into(self.root, None).0;
         let off = self.rec_offset(inserted);
-        let data = Data::make_mut(&mut self.data); 
-        let n = self.node_size - NODE_OVERHEAD - PAGE_ID_SIZE ;
-        debug_assert!(n == b.len()); 
-        data[off..off+n].copy_from_slice(&b[0..n]);       
+        let data = Data::make_mut(&mut self.data);
+        let n = self.node_size - NODE_OVERHEAD - PAGE_ID_SIZE;
+        debug_assert!(n == b.len());
+        data[off..off + n].copy_from_slice(&b[0..n]);
         self.set_child_page(inserted, cp);
-    }      
+    }
 
     /// Remove record from this page.
     pub fn remove(&mut self, db: &DB, r: &dyn Record) {
